Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: chrome/browser/browsing_data/origin_filter_builder.h

Issue 2248403002: Implement origin-based deletion of plugin data (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Addressed comments. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/browsing_data/origin_filter_builder.h
diff --git a/chrome/browser/browsing_data/origin_filter_builder.h b/chrome/browser/browsing_data/origin_filter_builder.h
index 61b9dd4a99b173d398f5cf7663905ef748c75c35..be410d351ca7c2911a51e4585ed241c1759eb608 100644
--- a/chrome/browser/browsing_data/origin_filter_builder.h
+++ b/chrome/browser/browsing_data/origin_filter_builder.h
@@ -18,11 +18,11 @@
// A class that constructs URL deletion filters (represented as GURL->bool
// predicates) that match certain origins.
//
// IMPORTANT NOTE: While this class does define cookie and channel IDs filtering
// methods, as required by the BrowsingDataFilterBuilder interface, it is not
// suitable for deletion of those data types, as they are scoped to eTLD+1.
// Instead, use RegistrableDomainFilterBuilder and see its documenation for
// more details.
class OriginFilterBuilder : public BrowsingDataFilterBuilder {
public:
// Constructs a filter with the given |mode| - whitelist or blacklist.
@@ -59,6 +59,12 @@ class OriginFilterBuilder : public BrowsingDataFilterBuilder {
base::Callback<bool(const std::string& channel_id_server_id)>
BuildChannelIDFilter() const override;
+ // Plugin site filter is not implemented in this subclass. Please use
+ // a BrowsingDataFilterBuilder with different scoping,
+ // such as RegistrableDomainFilterBuilder.
+ base::Callback<bool(const std::string& site)>
+ BuildPluginFilter() const override;
+
bool operator==(const OriginFilterBuilder& other) const;
protected:
@@ -18,11 +18,11 @@
// predicates) that match certain origins.
//
-// IMPORTANT NOTE: While this class does define cookie and channel IDs filtering
-// methods, as required by the BrowsingDataFilterBuilder interface, it is not
-// suitable for deletion of those data types, as they are scoped to eTLD+1.
-// Instead, use RegistrableDomainFilterBuilder and see its documenation for
-// more details.
+// IMPORTANT NOTE: While this class does define cookie, channel ID, and plugin
+// filtering methods, as required by the BrowsingDataFilterBuilder interface,
+// it is not suitable for deletion of those data types, as they are scoped
+// to eTLD+1. Instead, use RegistrableDomainFilterBuilder and see its
+// documenation for more details.
class OriginFilterBuilder : public BrowsingDataFilterBuilder {
public:

Powered by Google App Engine
This is Rietveld 408576698